"""
DB component
"""

from dataclasses import dataclass

from sqlalchemy import Column, Integer, String, create_engine
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import Session, sessionmaker

Base = declarative_base()


class ShortURL(Base):  # pylint: disable=too-few-public-methods
    """
    Class to describe the DB schema for ShortURLs
    """

    __tablename__ = "shorturl"

    id = Column(Integer, primary_key=True)
    shortcode = Column(String(128), unique=True, nullable=False)
    url = Column(String(2048), unique=False, nullable=False)
    fixed_views = Column(Integer, unique=False, nullable=False)
    expiry = Column(String(26), unique=False, nullable=False)


@dataclass
class ShortcodeDB:
    """
    Class to represent the database
    """

    url: str

    def session(self) -> Session:
        """
        Create a DB session

        Returns:
            Session: the DB session object
        """
        engine = create_engine(self.url)
        Base.metadata.create_all(engine)
        new_session = sessionmaker(bind=engine)
        return new_session()
